@@ -164,6 +164,9 @@ void FileInfo::setFromGFileInfo(const GObjectPtr<GFileInfo>& inf, const FilePath
         }
     }
 
+    isReadOnly_ = false; /* default is R/W */
+    isRemote_ = false; /* default is local */
+
     /* special handling for symlinks */
     if(g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK)) {
         mode_ &= ~S_IFMT; /* reset type */
@@ -204,14 +207,16 @@ void FileInfo::setFromGFileInfo(const GObjectPtr<GFileInfo>& inf, const FilePath
         if(!mimeType_) {
             mimeType_ = MimeType::inodeDirectory();
         }
-        isReadOnly_ = false; /* default is R/W */
         if(g_file_info_has_attribute(inf.get(), G_FILE_ATTRIBUTE_FILESYSTEM_READONLY)) {
             isReadOnly_ = g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_FILESYSTEM_READONLY);
         }
-        /* directories should be writable to be deleted by user */
         if(isReadOnly_ || !isWritable_) {
+            /* directories should be writable to be deleted by user */
             isDeletable_ = false;
         }
+        if(g_file_info_has_attribute(inf.get(), G_FILE_ATTRIBUTE_FILESYSTEM_REMOTE)) {
+            isRemote_ = g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_FILESYSTEM_REMOTE);
+        }
         break;
     case G_FILE_TYPE_SYMBOLIC_LINK:
 _file_is_symlink:
@@ -251,7 +256,10 @@ _file_is_symlink:
             if(g_key_file_load_from_file(kf, dot_dir.get(), G_KEY_FILE_NONE, nullptr)) {
                 CStrPtr icon_name{g_key_file_get_string(kf, "Desktop Entry", "Icon", nullptr)};
                 if(icon_name) {
-                    auto dot_icon = IconInfo::fromName(icon_name.get());
+                    // also allow relative icon paths
+                    auto dot_icon = IconInfo::fromName(g_strstr_len(icon_name.get(), -1, G_DIR_SEPARATOR_S)
+                                    ? path().relativePath(icon_name.get()).toString().get()
+                                    : icon_name.get());
                     if(dot_icon && dot_icon->isValid()) {
                         icon_ = dot_icon;
                     }
@@ -390,15 +398,14 @@ bool FileInfo::isExecutableType() const {
          they are native and have read permission */
         if(isNative() && (mode_ & (S_IRUSR|S_IRGRP|S_IROTH))) {
             if(isShortcut() && !target_.empty()) {
-                /* handle shortcuts from desktop to menu entries:
-                   first check for entries in /usr/share/applications and such
-                   which may be considered as a safe desktop entry path
-                   then check if that is a shortcut to a native file
-                   otherwise it is a link to a file under menu:// */
-                if (!g_str_has_prefix(target_.c_str(), "/usr/share/")) {
-                    auto target = FilePath::fromPathStr(target_.c_str());
-                    bool is_native = target.isNative();
-                    if (is_native) {
+                /* first check if this is a shortcut to a native file
+                   (otherwise it is a link to a file under menu://),
+                   then check for entries in /usr/share/applications and such
+                   which may be considered as a safe desktop entry path */
+                auto target = FilePath::fromPathStr(target_.c_str());
+                if(target.isNative()) {
+                    auto usrShare = FilePath::fromPathStr("/usr/share/");
+                    if(!usrShare.isPrefixOf(target)) {
                         return true;
                     }
                 }
