@@ -17,9 +17,10 @@ bool ThumbnailJob::localFilesOnly_ = true;
 int ThumbnailJob::maxThumbnailFileSize_ = 4096; // in KiB
 int ThumbnailJob::maxExternalThumbnailFileSize_ = -1;
 
-ThumbnailJob::ThumbnailJob(FileInfoList files, int size):
+ThumbnailJob::ThumbnailJob(FileInfoList files, int size, bool isRemote):
     files_{std::move(files)},
     size_{size},
+    isRemote_{isRemote},
     md5Calc_{g_checksum_new(G_CHECKSUM_MD5)} {
 }
 
@@ -66,12 +67,16 @@ QImage ThumbnailJob::loadForFile(const std::shared_ptr<const FileInfo> &file) {
         return QImage();
     }
 
+    if(localFilesOnly_ && isRemote_) {
+        return QImage();
+    }
+
     // thumbnails are stored in $XDG_CACHE_HOME/thumbnails/large|normal|failed
     QString thumbnailDir{QString::fromUtf8(g_get_user_cache_dir())};
     thumbnailDir += QLatin1String("/thumbnails/");
 
     // don't make thumbnails for files inside the thumbnail directory
-    if(FilePath::fromLocalPath(thumbnailDir.toLocal8Bit().constData()).isParentOf(file->dirPath())) {
+    if(file->dirPath() && FilePath::fromLocalPath(thumbnailDir.toLocal8Bit().constData()).isParentOf(file->dirPath())) {
         return QImage();
     }
 
@@ -88,7 +93,14 @@ QImage ThumbnailJob::loadForFile(const std::shared_ptr<const FileInfo> &file) {
         // if the file is changed to a symlink with the same time stamp
         auto target = file->target();
         if(!target.empty()) {
-            uri = FilePath::fromLocalPath(target.c_str()).uri();
+            if(file->dirPath()) {
+                // "FilePath::relativePath()" also covers absolute path names
+                // because "g_file_resolve_relative_path()" does
+                uri = file->dirPath().relativePath(target.c_str()).uri();
+            }
+            else {
+                uri = FilePath::fromLocalPath(target.c_str()).uri();
+            }
         }
     }
     if(!uri) {
@@ -253,7 +265,7 @@ QImage ThumbnailJob::generateThumbnail(const std::shared_ptr<const FileInfo>& fi
             && file->size() > static_cast<uint64_t>(maxExternalThumbnailFileSize_) * 1024) {
             return result;
         }
-        // try all available external thumbnailers for it until sucess
+        // try all available external thumbnailers for it until success
         int target_size = size_ > 256 ? 512 : size_ > 128 ? 256 : 128;
         file->mimeType()->forEachThumbnailer([&](const std::shared_ptr<const Thumbnailer>& thumbnailer) {
             if(thumbnailer->run(uri, thumbnailFilename.toLocal8Bit().constData(), target_size)) {
