@@ -73,6 +73,8 @@ FilePropsDialog::FilePropsDialog(Fm::FileInfoList files, QWidget* parent, Qt::Wi
         ui->contentsLabel->hide();
         ui->fileNumber->hide();
     }
+
+    resize(size().expandedTo(sizeHint())); // make sure that the labels are shown completely (a Qt bug?)
 }
 
 FilePropsDialog::~FilePropsDialog() {
@@ -764,6 +766,10 @@ void FilePropsDialog::initOwner() {
         if(userId != 0) { // on local filesystems, only root can do chown.
             ui->owner->setEnabled(false);
             ui->ownerGroup->setEnabled(userId == uid);
+            ui->ownerPerm->setEnabled(userId == uid);
+            ui->groupPerm->setEnabled(userId == uid);
+            ui->otherPerm->setEnabled(userId == uid);
+            ui->executable->setEnabled(userId == uid);
         }
     }
 }
